There is no need to force an line number entry (using previous location) for a temp label at unknown location.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@104740 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/AsmPrinter/DwarfDebug.cpp b/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
index 9aee593..acc168e 100644
--- a/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
+++ b/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
@@ -2289,12 +2289,11 @@
     return;
   }
 
   // If location is unknown then Use last known location for this DBG_VALUE 
   // instruction.
   if (MI->isDebugValue()) {
-    const MDNode *Scope = 
-      PrevInstLoc.getScope(Asm->MF->getFunction()->getContext());
-    PrevLabel = recordSourceLine(PrevInstLoc.getLine(), PrevInstLoc.getCol(), Scope);
+    PrevLabel = MMI->getContext().CreateTempSymbol();
+    Asm->OutStreamer.EmitLabel(PrevLabel);
     LabelsBeforeInsn[MI] = PrevLabel;
     return;
   }
@@ -2289,12 +2289,11 @@
   }
 
-  // If location is unknown then Use last known location for this DBG_VALUE 
+  // If location is unknown then use temp label for this DBG_VALUE 
   // instruction.
   if (MI->isDebugValue()) {